*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Lattice - Conditional      *;
*              Statements                 *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)");
run;

proc template;
  define statgraph notconditional;
    begingraph;
	  layout overlay;
	    boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	  endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all;
  by param;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "unconditional_boxplot";

** What do you notice in the output when you run this code? Correct! The interquartile range looks squashed. A log-transformation may make the plot better **;
proc sgrender data = adlbc_all template = notconditional;
  by param;
  format trtan trtfmt.;
run;

ods graphics / reset = all ;

** Changing the type of the axis when the paramter is Creatine Kinase - _BYVAL_ is very important here, i.e. using param will not work **;
** Added Entrytitle in 21MAR2016, and removed dynamic variable _byvar_ **;
proc template;
  define statgraph conditional;
    begingraph;
	dynamic _byval_;

	  if (_byval_ = "Creatine Kinase (U/L)") 
	    entrytitle _byval_;
	    layout overlay / yaxisopts=(type=log);
	      boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	    endlayout;

	  else
	     entrytitle _byval_;
	    layout overlay;
	      boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	    endlayout;
	  endif;

	endgraph;
  end;
run;



proc sort data = adlbc_all;
  by param;
run;

ods graphics / reset = all imagename = "conditional_boxplot";

** What do you notice in the output when you run this code? Correct! The interquartile range looks squashed. A log-transformation may make the plot better **;
proc sgrender data = adlbc_all template = conditional;
  by param;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)");
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;
