*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Boxplot - Gridded Layout   *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
run;

* Gridded Layout 2 rows *;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout gridded;
 	    * First Row;
	    layout overlay;
	      boxplot x = trtan y = base / group = trtan groupdisplay = cluster;
	    endlayout;

		* Second Row;
	    layout overlay;
	      boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	    endlayout;
	  endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all;
  by param;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_gridded1";

proc sgrender data = adlbc_all template = boxplot_template;
  by param;
  where param in ("Creatinine (umol/L)");
  format trtan trtfmt.;
run;


* Gridded Layout 2 columns *;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout gridded / columns = 2;
 	    * First Column;
	    layout overlay;
	      boxplot x = trtan y = base / group = trtan groupdisplay = cluster;
	    endlayout;

       * Second Column;
	    layout overlay;
	      boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	    endlayout;
	  endlayout;
	endgraph;
  end;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_gridded2";

proc sgrender data = adlbc_all template = boxplot_template;
  by param;
  where param in ("Creatinine (umol/L)");
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;
