*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Boxplot - Lattice Layout   *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
  where param in ("Creatinine (umol/L)");
run;

* Lattice Layout 2 columns *;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout lattice / columns = 2 columnweights=(0.6 0.4);

	    * First Column;
	    layout overlay;
	      boxplot x = trtan y = base / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Column;
	    layout overlay;
	      boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	    endlayout;

	  endlayout;
	endgraph;
  end;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_lattice1";

proc sgrender data = adlbc_all template = boxplot_template;
  by param;
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;


* Nested Layout 2 columns. 2 rows in second column *;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout lattice / columns = 2 columnweights=(0.5 0.5);  *----------------------------------;
                                                                                               *;
 	    * First Column;                                                                        *;
	    layout overlay;  *---------------------------------------------------------------;     *;
	      boxplot x = trtan y = base / group = trtan groupdisplay = cluster;            *;     *;
	    endlayout;  *--------------------------------------------------------------------;     *;
                                                                                               *;
		* Second Column;                                                                       *;
		layout lattice / rows = 2; *-----------------------------------------------------;     *;
                                                                                        *;     *;
		* First Row;                                                                    *;     *;
	      layout overlay;                                                               *;     *;
	        boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;          *;     *;
	      endlayout;                                                                    *;     *;
                                                                                        *;     *;
		* Second Row;                                                                   *;     *;
	      layout overlay;                                                               *;     *; 
	        barchart category = trtan response = aval / group = trtan stat = mean;      *;     *;
	      endlayout;                                                                    *;     *;
                                                                                        *;     *;
		endlayout;  *--------------------------------------------------------------------;     *;
                                                                                               *;
	  endlayout;  *-----------------------------------------------------------------------------;
	endgraph;
  end;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_bar_lattice1";

proc sgrender data = adlbc_all template = boxplot_template;
  by param;
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;
