*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Boxplot - Datapanel Layout *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;


%include "&path";
libname source "&inpath";

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

/* ADLBC */
data adlbc_all;
  set source.adlbc;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)", "Aspartate Aminotransferase (U/L)", "Alanine Aminotransferase (U/L)") and anl01fl = "Y";
run;

/* Datapanel - Scatterplot*/

proc template;
  define statgraph scatterpanel;
    begingraph;
	  layout datapanel classvars = (param);
	      layout prototype; * Datapanel uses layout prototype;
		    scatterplot x = visitnum y = aval / group = trta groupdisplay = cluster jitter = auto;
		  endlayout;
	  endlayout;
	endgraph;
  end;
run;

ods listing gpath = "&outpath";
ods graphics on / reset = all imagename = "scatterpanel";
proc sgrender data = adlbc_all template = scatterpanel;
run;

proc sort data = adlbc_all;
  by param paramcd visitnum trta;
run;

* Going to do a boxplot. Need to summarize the data first for DATAPANEL. Not as simple as using scatterplot;

proc univariate data = adlbc_all noprint;
  by param paramcd visitnum trta;
  var aval;
  output out = boxplotstats Min = Min Max = Max Median = Median Mean = Mean Q1 = q1 q3 = q3;
run;

proc transpose data = boxplotstats out = boxplotstats2;
  by param paramcd visitnum trta;
  var Median Mean q1 q3 Min Max;
run;

* 2 labs - common row axis (axis should be transformed);

proc template;
  define statgraph boxplotpanel;
    begingraph;
	  layout datapanel classvars = (param);
	      layout prototype;
		      boxplotparm x = visitnum y = col1 stat = _NAME_ / group = trta groupdisplay = cluster name = "trtleg";
		  endlayout;

		  sidebar;
		      discretelegend "trtleg";
		  endsidebar;

	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "boxpanel";
proc sgrender data = boxplotstats2 template = boxplotpanel;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)");
run;

* 2 labs - common row axis (log scale);

proc template;
  define statgraph boxplotpanellog;
    begingraph;
	  layout datapanel classvars = (param) /
        rowaxisopts = (type = log label = "Lab Intensity Values");
	      layout prototype;
		    boxplotparm x = visitnum y = col1 stat = _NAME_ / group = trta groupdisplay = cluster name = "trtleg";
		  endlayout;

		  sidebar;
		      discretelegend "trtleg";
		  endsidebar;
	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "boxpanellog1";
proc sgrender data = boxplotstats2 template = boxplotpanellog;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)");
run;

ods graphics / reset = all;
goptions reset = all;

* 2 labs - Own row axis;

proc template;
  define statgraph boxplotpanellog;
    begingraph;
	  layout datapanel classvars = (param) /
        rowaxisopts = (type = log label = "Lab Intensity Values")  rowdatarange=union;

	      layout prototype;
		    boxplotparm x = visitnum y = col1 stat = _NAME_ / group = trta groupdisplay = cluster name = "trtleg";
		  endlayout;

		  sidebar;
		      discretelegend "trtleg";
		  endsidebar;
	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "boxpanellog2";
proc sgrender data = boxplotstats2 template = boxplotpanellog;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)");
run;

* 4 cells - 4 labs;
ods graphics / reset = all;
goptions reset = all;

proc template;
  define statgraph boxplotpanellog;
    begingraph;
	  layout datapanel classvars = (param) /
	    columns = 2
        rowaxisopts = (type = log label = "Lab Intensity Values") rowdatarange=union;

	      layout prototype;
		    boxplotparm x = visitnum y = col1 stat = _NAME_ / group = trta groupdisplay = cluster name = "trtleg";
		  endlayout;

		  sidebar;
		      discretelegend "trtleg";
		  endsidebar;
	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "boxpanellog3";
proc sgrender data = boxplotstats2 template = boxplotpanellog;
run;

ods graphics / reset = all;
goptions reset = all;
