*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Lattice - independent axis *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
  where param in ("Creatine Kinase (U/L)", "Creatinine (umol/L)", "Aspartate Aminotransferase (U/L)", "Alanine Aminotransferase (U/L)") and anl01fl = "Y";
run;

* Lattice Layout 2 columns, 2 rows. Independent axis. Internal Axes *;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout lattice / columns = 2 rows = 2;

	    * First Column, First Row;
	    layout overlay / yaxisopts = (type = log label = "Alanine Aminotransferase (U/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Alanine Aminotransferase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Columnm, First Row;
	    layout overlay / yaxisopts = (type = log label = "Aspartate Aminotransferase (U/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Aspartate Aminotransferase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

		* First Column, Second Row;
	    layout overlay / yaxisopts = (type = log label = "Creatine Kinase (U/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Creatine Kinase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Columnm, Second Row;
	    layout overlay / yaxisopts = (type = log label = "Creatinine (umol/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Creatinine (umol/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	  endlayout;
	endgraph;
  end;
run;

* Note the following warning is fine "WARNING: The data for boxes is incomplete or invalid. Some boxes will not be drawn".;
*It is because the ifn function is being used and this sets the results to missing when the parameter is not the parameter of interest.;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_lattice_independent1";

proc sgrender data = adlbc_all template = boxplot_template;
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;


* Lattice Layout 2 columns, 2 rows. External axis *;

proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout lattice / columns = 2 rows = 2 columndatarange = union;

	    * First Column, First Row;
	    layout overlay / yaxisopts = (type = log label = "Alanine Aminotransferase (U/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Alanine Aminotransferase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Columnm, First Row;
	    layout overlay / yaxisopts = (type = log label = "Aspartate Aminotransferase (U/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Aspartate Aminotransferase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

		* First Column, Second Row;
	    layout overlay / yaxisopts = (type = log label = "Creatine Kinase (U/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Creatine Kinase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Columnm, Second Row;
	    layout overlay / yaxisopts = (type = log label = "Creatinine (umol/L)");
	      boxplot x = visitnum y = eval(ifn(param = "Creatinine (umol/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

		* External Axes;
		columnaxes;
          columnaxis / griddisplay=on display=(label tickvalues)
            labelattrs=(weight=bold);
          columnaxis / griddisplay=on display=(label tickvalues)
            labelattrs=(weight=bold);
        endcolumnaxes;

	  endlayout;
	endgraph;
  end;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_lattice_independent2";

proc sgrender data = adlbc_all template = boxplot_template;
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;


* Making labels appear similar to DataPanel layout;
data adlbc_all2;
  set adlbc_all;
  alt = "Alanine Aminotransferase (U/L)";
  ast = "Aspartate Aminotransferase (U/L)";
  ck = "Creatine Kinase (U/L)";
  creat = "Creatinine (umol/L)";
run;

proc sort data = adlbc_all2;
  by param visitnum;
run;

*Updated y-axis to logscale on 21MAR2016;
proc template;
  define statgraph boxplot_template;
    begingraph;
	  layout lattice / columns = 2 rows = 2;

	    * First Column, First Row;
	    layout overlay / yaxisopts = (type = log display = (line ticks tickvalues));
		  innermargin / align = top;
		    blockplot x = visitnum block = alt / valuehalign = center display = (outline values);
		  endinnermargin;
	      boxplot x = visitnum y = eval(ifn(param = "Alanine Aminotransferase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Columnm, First Row;
	    layout overlay / yaxisopts = (type = log display = (line ticks tickvalues));
		  innermargin / align = top;
		    blockplot x = visitnum block = ast / valuehalign = center display = (outline values);
		  endinnermargin;
	      boxplot x = visitnum y = eval(ifn(param = "Aspartate Aminotransferase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

		* First Column, Second Row;
	    layout overlay / yaxisopts = (type = log display = (line ticks tickvalues));
		  innermargin / align = top;
		    blockplot x = visitnum block = ck / valuehalign = center display = (outline values);
		  endinnermargin;
	      boxplot x = visitnum y = eval(ifn(param = "Creatine Kinase (U/L)", aval, .)) / group = trtan groupdisplay = cluster;
	    endlayout;

	    * Second Columnm, Second Row;
	    layout overlay / yaxisopts = (type = log display = (line ticks tickvalues));
		  innermargin / align = top;
		    blockplot x = visitnum block = creat / valuehalign = center display = (outline values);
		  endinnermargin;
	      boxplot x = visitnum y = eval(ifn(param = "Creatinine (umol/L)", aval, .)) / group = trtan groupdisplay = cluster name = "leg";
	    endlayout;

		* Legend;
        sidebar / align = bottom;
		  discretelegend "leg";
		endsidebar;

	  endlayout;
	endgraph;
  end;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_lattice_independent3";

proc sgrender data = adlbc_all2 template = boxplot_template;
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;
