*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Unicode Legend in KM       *;
* Purpose:     Hands-On GTL               *;
*              SAS Global Forum 2016      *;
*	           5760                       *;
*-----------------------------------------*;         
* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,&b,%str(setup.sas)));
  %put &path;
%mend;
%start;

data BMT;
  set sashelp.BMT;
  if group = "ALL" then groupn = 1;
  else if group = "AML-Low Risk" then groupn = 2;
  else if group = "AML-High Risk" then groupn = 3;
run;

ods listing gpath = "&outpath";
ods graphics on / reset = all imagename = "KM_default";

proc lifetest data=BMT plots=survival(atrisk=0 to 2500 by 500) outsurv = outsurv;
   time T * Status(0);
   strata Groupn / test=logrank adjust=sidak;
run;

* Filling down empty survival calculations. Im sure previous versions done this.;
data outsurv2;
  set outsurv;
  by stratum;
  retain survival2;
  if survival ne . then survival2 = survival;
run;

ods escapechar  = "^";

proc template;
  define statgraph kaplan;
    begingraph;
      layout overlay / yaxisopts = (label = "Survial Probability" linearopts = (viewmin = 0 viewmax =1)) xaxisopts = (label = "Months");
        stepplot y = eval(ifn(stratum = 1, survival2, .)) x = eval(ifn(stratum = 1, t, .)) / name = "leg" legendlabel = "^{unicode '2264'x} 65" lineattrs = GRAPHDATA1;
        scatterplot y = eval(ifn(stratum = 1 and _CENSOR_ = 1, survival2, .)) x = eval(ifn(stratum = 1 and _CENSOR_ = 1, t, .)) / markerattrs = (color = GRAPHDATA1:color symbol = plus);

        stepplot y = eval(ifn(stratum = 2, survival2, .)) x = eval(ifn(stratum = 2, t, .)) / name = "leg2" legendlabel = "> 65" lineattrs = GRAPHDATA2;
        scatterplot y = eval(ifn(stratum = 2 and _CENSOR_ = 1, survival2, .)) x = eval(ifn(stratum = 2 and _CENSOR_ = 1, t, .)) / markerattrs = (color = GRAPHDATA2:color symbol = plus);

        discretelegend "leg" "leg2";

      endlayout;
    endgraph;
  end;
run;

ods graphics on / reset = all imagename = "KM_with_Unicode_Legend";

proc sgrender data = outsurv2 template = kaplan;
run;

ods graphics / reset = all;
goptions reset = all;
