*--------------------------------------*;  
* Author:  Kriss Harris                *;
* Email:   ITALJET125@YAHOO.COM        *;
* Purpose: Picture This: Hands on SAS  *;
*          Graphics Session            *;
*	       PharmaSUG 2015 HT01         *;
*--------------------------------------*;                              

%let outpath =U:\pharmasug\2015\ZQJ_HOWHarris\HT01\output\figures;
%let inpath = U:\pharmasug\2015\ZQJ_HOWHarris\HT01\sasdatasets;

libname source "&inpath";

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

/* ADLBC */
data adlbc_all;
  set source.adlbc;
run;

data adlbc2;
  set source.adlbc;
  where param = "Creatinine (umol/L)" and trtan = 54 and anl01fl = "Y";
  /* Creating variables for Vector Statement */
  x1 = 8.5;
  y1 = 160;
run;

/* ADVS */
data advs;
  set source.advs;
  where SAFFL and "Y" and ANL01FL = "Y" and paramcd = "TEMP";
run;

/* ADTTE */
data adtte;
  set source.adtte;
run;

/* ADAE */
data adae;
  set source.adae;
run;

proc sort data = adae;
  by usubjid aedecod;
run;

/* DATASET FOR WATERFALL PLOT */
data waterfall_group;
  call streaminit(123);
  do i = 1001 to 1005;
	Patient = i;
	Group = "Group 1";
	pchgb = rand("normal", 0,30);
	output;
  end;
  do i = 1006 to 1010;
	Patient = i;
	Group = "Group 2";
	pchgb = rand("normal", 0,30);
	output;
  end;
  do i = 1011 to 1015;
	Patient = i;
	Group = "Group 3";
	pchgb = rand("normal", 0,30);
	output;
  end;
  do i = 1016 to 1020;
	Patient = i;
	Group = "Group 4";
	pchgb = rand("normal", 0,30);
	output;
  end;
  do i = 1021 to 1025;
	Patient = i;
	Group = "Group 5";
	pchgb = rand("normal", 0,30);
	output;
  end;
run;

proc sort data = waterfall_group;
  by descending pchgb;
run; 

data waterfall_group2;
  set waterfall_group;
  start = _N_;
  rename Patient = label;
  fmtname = "order";
run;

proc format cntlin = waterfall_group2;
run;

/* Simulating data for Box plots and bar graphs */
data boxplots;
  CALL STREAMINIT(2);

  do i = 1 to 15;
    Treatment = "Treatment A"; 
    Day = 1;
    Results = RAND('NORMAL',25,10); 
    output;
  end;

  do i = 16 to 30;
    Treatment = "Treatment A"; 
    Day = 2;
    Results = RAND('NORMAL',35,10); 
    output;
  end;

  do i = 31 to 45;
    Treatment = "Treatment B"; 
    Day = 1;
    Results = RAND('NORMAL',55,10);
    output;
  end;

  do i = 46 to 60;
    Treatment = "Treatment B"; 
    Day = 2;
    Results = RAND('NORMAL',65,10);
    output;
  end;
run;

ods graphics / reset = all;
goptions reset = all;
ods listing gpath = "&outpath."; /* Resetting all titles and footnotes and setting outpath */

*---------------------------------------------------------------------------------------*;
*														       						    *;
*																				        *;
*					                     SGPLOT         							    *;
*																				        *;
*																				        *;
*---------------------------------------------------------------------------------------*;


*--------------------------------------------------------------------------------*;
*																				 *;
*					              SAS 9.3 Graphs							     *;	
*																				 *;
*--------------------------------------------------------------------------------*;


*---------------------------------------------------------------*;
*					    Basic Plots								*;	
*---------------------------------------------------------------*;

/* SCATTER */
ods graphics on / reset = all imagename = "scatter";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y" and visitnum = 4;
  scatter x = base y = aval;
run;

/* Square plot */
ods graphics on / reset = all imagename = "scatter_square" height = 3in width = 3in;
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y" and visitnum = 4;
  scatter x = base y = aval;
run;

/* SERIES */
ods graphics on / reset = all imagename = "series_not_sorted";
proc sgplot data = advs;
  by param;
  series x = ady y = aval / group = trta ;
run;

/* Important to sort your data by the x-variable */
proc sort data = advs out = advs_series_sorted;
by param ady;
run;

ods graphics on / reset = all imagename = "series_sorted";
proc sgplot data = advs_series_sorted;
  by param;
  series x = ady y = aval / group = trta ;
run;

/* STEP */
/* Obtaining survival dataset first */
ods graphics on / reset = all;
proc lifetest data = adtte outsurv = surv;
  time aval * cnsr(1);
  strata trta;
run;

data surv2;
  set surv;
  if _censor_ = 1 then survival_censor = survival;
run;

ods graphics on / reset = all imagename = "step";
proc sgplot data = surv2;
  step x = aval y = survival / group = trta;
  scatter x = aval y = survival / group = trta markerattrs = (symbol = plus);
run;

/* BAND */
/* Obtaining confidence intervals first */
ods graphics off / reset = all;
proc mixed data = adlbc2;
  where ablfl ne "Y";
  model aval = base / outp = reg_estimates;
run;

ods graphics on / reset = all imagename = "band_not_sorted";
proc sgplot data = reg_estimates;
  by param;
  band y = pred lower = lower upper = upper;
run;

proc sort data = reg_estimates out = reg_estimates_sorted;
  by param pred;
run;

ods graphics on / reset = all imagename = "band_sorted";
proc sgplot data = reg_estimates_sorted;
  by param;
  band y = pred lower = lower upper = upper;
  xaxis label = "Actual";
run;

ods graphics on / reset = all imagename = "band_with_scatter_sorted";
proc sgplot data = reg_estimates_sorted;
  by param;
  band y = pred lower = lower upper = upper;
  scatter x = base y = aval; /* scatterplot labels are used regardless of order */
run;

/* BUBBLE */
ods graphics on / reset = all imagename = "bubble";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y" ;
  bubble x = visitnum y = aval size = base ;
run;

/* HIGH-LOW */
ods graphics on / reset = all imagename = "highlow";
proc sgplot data = adae;
  by usubjid;
  where usubjid = "01-718-1427" /* and (astdy ne . and aendy ne .) */;
  highlow y = aedecod low = astdy high = aendy / group = aesev type = bar barwidth = 0.8;
run;

/* NEEDLE */
/* Comparing to Bar Chart First */
ods graphics on / reset = all imagename = "needle_but_bar";
proc sgplot data = adlbc2;
  by param;
  where racen = 2;
  vbar adt / response = aval group = sex stat = mean;
run;

/* Needle Plot */
ods graphics on / reset = all imagename = "needle";
proc sgplot data = adlbc2;
  by param;
  where racen = 2;
  needle x = adt y = aval / group = sex lineattrs = (thickness = 2);
run;

/* VECTOR */
ods graphics on / reset = all imagename = "vector";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  scatter x = visitnum y = aval;
  vector x = x1 y = y1 / xorigin = 10 yorigin = 160 lineattrs = (color = black thickness = 2);
run; 

*---------------------------------------------------------------*;
*				 Fit and Confidence Plots					    *;	
*---------------------------------------------------------------*;
/* REG */
ods graphics on / reset = all imagename = "reg";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  reg x = base y = aval;
run;

/* LOESS */
ods graphics on / reset = all imagename = "loess";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  loess x = base y = aval;
run;

/* PBSPLINE */
ods graphics on / reset = all imagename = "pbspline";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  pbspline x = base y = aval;
run;

/* ELLIPSE */
ods graphics on / reset = all imagename = "ellipse_no_labels";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  ellipse x = base y = aval;
run;

ods graphics on / reset = all imagename = "ellipse_labels";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  ellipse x = base y = aval;
  xaxis label = "Baseline Creatinine (umol/L) values";
  yaxis label = "Post-baseline Creatinine (umol/L) values";
run;

*---------------------------------------------------------------*;
*				      Distribution Plots					    *;	
*---------------------------------------------------------------*;

/* HBOX */
ods graphics on / reset = all imagename = "hbox";
proc sgplot data = adlbc2;
  by param;
  hbox aval / category = visitnum;
run; 

/* VBOX */
ods graphics on / reset = all imagename = "vbox";
proc sgplot data = adlbc2;
  by param;
  vbox aval / category = visitnum;
run; 

/* HISTOGRAM */
ods graphics on / reset = all imagename = "histogram";
proc sgplot data = adlbc2;
  by param;
  histogram aval;
run; 

/* DENSITY */
ods graphics on / reset = all imagename = "density";
proc sgplot data = adlbc2;
  by param;
  density aval;
run;

*---------------------------------------------------------------*;
*				      Categorisation Plots					    *;	
*---------------------------------------------------------------*;

/* DOT */
ods graphics on / reset = all imagename = "dot";
proc sgplot data = adlbc2;
  by param;
  dot visitnum / response = aval stat = mean limitstat = stddev group = sex
    markerattrs= (symbol = circlefilled);
run;

/* HBAR */
ods graphics on / reset = all imagename = "hbar";
proc sgplot data = adlbc2;
  by param;
  hbar visitnum / response = aval stat = mean;
run;

/* HLINE */
ods graphics on / reset = all imagename = "hline";
proc sgplot data = adlbc2;
  by param;
  hline visitnum / response = aval stat = mean;  
run;

/* HBAR and HLINE */
ods graphics on / reset = all imagename = "hbar_hline_wrong_order";
proc sgplot data = adlbc2;
  by param;
  hline visitnum / response = aval stat = mean;
  hbar visitnum / response = aval stat = mean;
run;

/* Overlay order is important */
ods graphics on / reset = all imagename = "hbar_hline_right_order";
proc sgplot data = adlbc2;
  by param;
  hbar visitnum / response = aval stat = mean;
  hline visitnum / response = aval stat = mean;
run;

/* VBAR */
ods graphics on / reset = all imagename = "vbar";
proc sgplot data = adlbc2;
  by param;
  vbar visitnum / response = aval stat = mean;
run;

/* VLINE */
ods graphics on / reset = all imagename = "vline";
proc sgplot data = adlbc2;
  by param;
  vline visitnum / response = aval  stat = mean;  
run;

/* VBARPARM and (HBARPARM)*/
ods graphics on / reset = all imagename = "vbarparm";
proc sgplot data = waterfall_group2;
  vbarparm category =  start  response = pchgb / group = group grouporder = ascending;
  format start order.;
  xaxis label = "Patient";
  yaxis label = '% Change From Baseline';
run;

/* WATERFALL */
ods graphics on / reset = all imagename = "waterfall";
proc sgplot data = waterfall_group2;
  waterfall category = start response = pchgb / colorgroup = group;
  format start order.;
  xaxis label = "Patient";
  yaxis label = 'Stacked % Change From Baseline';
run;

*---------------------------------------------------------------*;
*				            Others					            *;	
*---------------------------------------------------------------*;

/* INSET */

/* First Obtaining R-square value */
ods graphics off / reset = all;
proc reg data = adlbc2;
  by param;
  where ablfl ne "Y";
  model aval = base;
run;
quit;

ods escapechar = "*";
ods graphics on / reset = all imagename = "inset";
proc sgplot data = adlbc2 noautolegend;
  by param;
  where ablfl ne "Y";
  inset "R*{sup '2'} = 0.8278" / border position = topleft;
  reg x = base y = aval / nomarkers lineattrs = (thickness = 0); /* Not displaying for now */
run;

ods escapechar = "*";
ods graphics on / reset = all imagename = "inset_and_reg";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  inset "R*{sup '2'} = 0.8278" / border position = topleft;
  reg x = base y = aval;
run;

/* KEYLEGEND */
ods graphics on / reset = all imagename = "keylegend_default";
proc sgplot data = adae;
  by usubjid;
  where usubjid = "01-718-1427"; 
  highlow y = aedecod low = astdy high = aendy / group = aesev type = bar barwidth = 0.8 name = "aesevg";
run;

ods graphics on / reset = all imagename = "keylegend1";
proc sgplot data = adae;
  by usubjid;
  where usubjid = "01-718-1427"; 
  highlow y = aedecod low = astdy high = aendy / group = aesev type = bar barwidth = 0.8 name = "aesevg";
  keylegend "aesevg" / across = 1;
run;

ods graphics on / reset = all imagename = "keylegend2";
proc sgplot data = adae;
  by usubjid;
  where usubjid = "01-718-1427"; 
  highlow y = aedecod low = astdy high = aendy / group = aesev type = bar barwidth = 0.8 name = "aesevg";
  keylegend "aesevg" / location = inside across = 1;
run;


/* REFLINE */
ods graphics on / reset = all imagename = "refline";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y";
  reg x = base y = aval;
  refline A1LO / axis = y;
run;

ods graphics on / reset = all imagename = "refline_sex_split";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y" and sex = "M";
  reg x = base y = aval;
  refline A1LO / axis = y;
  refline A1HI / axis = y;
run;

ods graphics on / reset = all imagename = "refline_sex_split_with_range";
proc sgplot data = adlbc2;
  by param;
  where ablfl ne "Y" and sex = "M";
  reg x = base y = aval;
  refline A1LO / axis = y;
  refline A1HI / axis = y;
  yaxis min = 60;
run;


*--------------------------------------------------------------------------------*;
*																				 *;
*					              SAS 9.4 Graphs							     *;	
*																				 *;
*--------------------------------------------------------------------------------*;

/* XAXISTABLE */

/* First using yaxis offset option */

proc sql;
  create table adlbc3 as 
  select *, round(avg(aval),0.01) as avgvisit, put(round(avg(aval),0.01), best.) as avgvisitc, strip(put(count(aval), best.)) as nvisitc, "N" as nlabel, 
    "Mean" as avglabel
  from adlbc2
  group by visitnum;
quit;

/* Only keeping the summarised value of the first group to enable clear summary displays on the graph */
data adlbc4;
  set adlbc3;
  by visitnum;
  if first.visitnum = 0 then do;
    avgvisitc = "";
    nvisitc = "";
  end;
run;

ods graphics on / reset = all imagename = "xaxistable_oldway";
proc sgplot data = adlbc4 noautolegend;
  vbarparm category = visitnum response = avgvisit;
  scatter x = visitnum y = nlabel / markerchar = nvisitc y2axis;
  scatter x = visitnum y = avglabel / markerchar = avgvisitc y2axis;
  yaxis offsetmin = 0.2 label = "Mean Analysis Value";
  y2axis type = discrete display = (nolabel) offsetmax = 0.85;
run;

ods graphics on / reset = all imagename = "xaxistable_newerway";
proc sgplot data = adlbc2;
  vbar visitnum / response = aval stat = mean; 
  xaxistable aval / stat = freq location = inside;
  xaxistable aval / stat = mean location = inside;
run;

*---------------------------------------------------------------------------------------*;
*														       						    *;
*																				        *;
*					                     GTL             							    *;
*																				        *;
*																				        *;
*---------------------------------------------------------------------------------------*;

/* Datapanel */

proc template;
  define statgraph scatterpanel;
    begingraph;
	  layout datapanel classvars = (param);
	      layout prototype;
		    scatterplot x = visitnum y = aval / group = trta;
		  endlayout;
	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "scatterpanel";
proc sgrender data = adlbc_all template = scatterpanel;
  where paramcd in ("ALT", "AST") and anl01fl = "Y";
run;

proc sort data = adlbc_all;
  by param paramcd visitnum trta;
run;

proc univariate data = adlbc_all noprint;
  where anl01fl = "Y" and paramcd in ("ALT", "AST");
  by param paramcd visitnum trta;
  var aval;
  output out = boxplotstats Min = Min Max = Max Median = Median Mean = Mean Q1 = q1 q3 = q3;
run;

proc transpose data = boxplotstats out = boxplotstats2;
  by param paramcd visitnum trta;
  var Median Mean q1 q3 Min Max;
run;

proc template;
  define statgraph boxplotpanel;
    begingraph;
	  layout datapanel classvars = (param);
	      layout prototype;
		      boxplotparm x = visitnum y = col1 stat = _NAME_ / group = trta groupdisplay = cluster name = "trtleg";
		  endlayout;

		  sidebar;
		      discretelegend "trtleg";
		  endsidebar;

	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "boxpanel";
proc sgrender data = boxplotstats2 template = boxplotpanel;
  where paramcd in ("ALT", "AST");
run;

proc template;
  define statgraph boxplotpanellog;
    begingraph;
	  layout datapanel classvars = (param) /
        rowaxisopts = (type = log label = "Lab Intensity Values");
	      layout prototype;
		    boxplotparm x = visitnum y = col1 stat = _NAME_ / group = trta groupdisplay = cluster name = "trtleg";
		  endlayout;

		  sidebar;
		      discretelegend "trtleg";
		  endsidebar;
	  endlayout;
	endgraph;
  end;
run;

ods graphics on / reset = all imagename = "boxpanellog";
proc sgrender data = boxplotstats2 template = boxplotpanellog;
  where paramcd in ("ALT", "AST");
run;



/*------------------------------------------------------------------------*/


/* Different Section */

/**** Adding Jitter ******/
ods html close;
ods graphics / reset = all imagename = "scatterjitter" imagefmt=png;
ods listing gpath = "&outpath.";

proc sgplot data = boxplots;
  scatter y = results x = treatment / group = treatment jitter;
run;

ods graphics / reset = all;

/* Attribute Maps */
ods html close;
ods graphics / reset = all imagename = "scatterattr" imagefmt=png;
ods listing gpath = "&outpath.";

data myattrmap;
  length markercolor $5 markersymbol $13;
  input ID $1-4 value $6-17 markercolor $ markersymbol $;
  datalines;
myid Treatment A black diamondfilled
myid Treatment B blue starfilled
;
run;

proc sgplot data = boxplots dattrmap = myattrmap;
  scatter y = results x = treatment / group = treatment attrid = myid;
run;

ods graphics / reset = all;

/* Adding Annotation */
data anno1;
  infile datalines dlm = '#';
  length x1space $11 y1space $9 x2space $11 y2space $9 label $17;
  input function $ x1 y1 label x2 y2 textcolor $ linecolor $ height width x1space $ y1space $ x2space $ y2space $ direction $ anchor $ ;
datalines;
oval # 98 # 35 #                   # .  # .  # blue #      # 4 # 4  # wallpercent #datavalue # wallpercent #datavalue #   #
arrow# 95 # 34 #                   # 85 # 25 #      # blue # . # .  # wallpercent #datavalue # wallpercent #datavalue #IN # TOPRIGHT
text # 83 # 25 # Potential Outlier # .  #    #      #      # . # 20 # wallpercent #datavalue # wallpercent #datavalue #  # TOPRIGHT
;
run;

ods listing gpath = "&outpath.";

ods graphics / reset = all imagename = "scatteranno";
proc sgplot data = boxplots sganno = anno1;
  scatter y = results x = treatment / group = treatment;
run; 
