*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Histogram Panel            *;
* Purpose:     Hands-On GTL               *;
*              SAS Global Forum 2016      *;
*	           5760                       *;
*-----------------------------------------*;

data test;
  drop i;
    do group='A','B','C','D','E','F','G','H';
      do i=1 to 100;
        if group='A' then x=25 + 8*rannor(2345);
        else x=1500 + 8*rannor(12345);
        output;
      end;
    end;
run;

ods listing gpath = "&outpath";
ods graphics on / reset = all imagename = "Histogram_Univariate_default";

title 'Comparative plots';
proc univariate data=test noprint;
  class group;
  var x;
  histogram x / vscale=count normal(noprint) ncols=4;
  inset normal(mu sigma);
run;
title;

* Sorting the data *;

proc sort data = test;
  by group x;
run;

/* Adding a numeric variable to the dataset to identify histogram plot */

data test2;
  set test;
  by group x;
  retain groupn 0;
  if first.group then groupn = groupn + 1;
run;

/* Creating Macro Variables for group labels */

proc sql noprint;
  select distinct(group) into :lab1 - :lab8
  from test2;
quit;

%macro graph(number);

proc template;
  define statgraph histogram_with_statistics;
    mvar lab1 lab2 lab3 lab4 lab5 lab6 lab7 lab8; /* Including Macro Variables for Labels */
      begingraph;
        layout lattice /columns = 4 rowdatarange = unionall /* Making y-axis consistent */;

        /* Using external axis */
        rowaxes;
           rowaxis;
           rowaxis; /* Will need to add in a rowaxis for each plot */
        endrowaxes;


        %do i = 1 %to &number;
          layout overlay / xaxisopts = (LABEL = LAB&i);
            histogram eval(ifn(groupn = &i, x, .));
          endlayout;
        %end;
        endlayout;
      endgraph;
  end;
run;

%mend;
%graph(8)

ods graphics / reset = all imagename = "Panelled Histogram";

proc sgrender data = test2 template = histogram_with_statistics;
run;

ods graphics / reset = all;
goptions reset = all;
